/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.formbean;

import java.util.Calendar;
import java.util.Date;

import se.vgregion.ifeed.service.solr.DateFormatter;
import se.vgregion.ifeed.service.solr.DateFormatter.DateFormats;
import se.vgregion.ifeed.types.FilterType.Filter;
import se.vgregion.ifeed.types.MetadataType;

public class FilterFormBean {
    private Filter filter;
    private String filterValue;
    private int validFromYear;
    private int validFromMonth;
    private int validFromDay;

    public FilterFormBean() {
        setFilterValue(new Date());
    }

    public Filter getFilter() {
        return filter;
    }

    public void setFilter(Filter filter) {
        this.filter = filter;
    }

    public String getFilterValue() {
        if (filter.getMetadataType() == MetadataType.DATE) {
            filterValue = DateFormatter.format(validFromYear, validFromMonth+1, validFromDay, DateFormats.SOLR_DATE_FORMAT);
        }
        return filterValue;
    }

    public void setFilterValue(String filterValue) {
        this.filterValue = filterValue;
    }

    public void setFilterValue(Date d) {
        Calendar c = Calendar.getInstance();
        c.setTime(d);
        validFromYear = c.get(Calendar.YEAR);
        validFromMonth = c.get(Calendar.MONTH);
        validFromDay = c.get(Calendar.DATE);
    }

    public void setValidFromYear(int validFromYear) {
        this.validFromYear = validFromYear;
    }

    public void setValidFromMonth(int validFromMonth) {
        //In Java Calendar January = 0, December = 11
        this.validFromMonth = validFromMonth;
    }

    public void setValidFromDay(int validFromDay) {
        this.validFromDay = validFromDay;
    }

    public int getValidFromDay() {
        return validFromDay;
    }
    public int getValidFromMonth() {
        return validFromMonth;
    }
    public int getValidFromYear() {
        return validFromYear;
    }
}
